@@ -726,6 +726,7 @@ class dyagram:
             for i in self.topology["devices"]:
                 if i['inventory_ip'] == device:
                     i['hostname'] = lldp_nei_json['hostname']
+                    print(lldp_nei_json['hostname'])
                     lldp_nei_json.pop("hostname")
                     i['layer2'] = lldp_nei_json
                     break
@@ -734,6 +735,7 @@ class dyagram:
             self._devices_queried.append(device)
         except:
             tb = self.get_traceback()
+            print("EXCEPTION THROWN WHEN TRYING TO GET HOSTNAME")
             self.log.info(f"EXCEPTION01 THROWN IN _discover_lldp_neighbors_by_ssh : {tb}")
 
 
